==> gurux.dlms-4.0.61-sources.jar: gurux/dlms/enums/DateTimeSkips.java <==
//
// --------------------------------------------------------------------------
//  Gurux Ltd
// 
//
//
// Filename:        $HeadURL$
//
// Version:         $Revision$,
//                  $Date$
//                  $Author$
//
// Copyright (c) Gurux Ltd
//
//---------------------------------------------------------------------------
//
//  DESCRIPTION
//
// This file is a part of Gurux Device Framework.
//
// Gurux Device Framework is Open Source software; you can redistribute it
// and/or modify it under the terms of the GNU General Public License 
// as published by the Free Software Foundation; version 2 of the License.
// Gurux Device Framework is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of 
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
// See the GNU General Public License for more details.
//
// More information of Gurux products: https://www.gurux.org
//
// This code is licensed under the GNU General Public License v2. 
// Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
//---------------------------------------------------------------------------

package gurux.dlms.enums;

import java.util.HashSet;
import java.util.Set;

/*
 * DataType enumerates skipped fields from date time.
 */
public enum DateTimeSkips {
    /**
     * Year part of date time is skipped.
     */
    YEAR(1),

    /**
     * Month part of date time is skipped.
     */
    MONTH(2),

    /**
     * Day part is skipped.
     */
    DAY(4),

    /**
     * Day of week part of date time is skipped.
     */
    DAY_OF_WEEK(8),

    /**
     * Hours part of date time is skipped.
     */
    HOUR(0x10),

    /**
     * Minute part of date time is skipped.
     */
    MINUTE(0x20),

    /**
     * Second part of date time is skipped.
     */
    SECOND(0x40),

    /**
     * Hundreds of seconds part of date time is skipped.
     */
    MILLISECOND(0x80),

    /**
     * Devitation is not used.
     */
    DEVITATION(0x100),

    /**
     * Status is not used.
     */
    STATUS(0x200);

    private int value;

    /*
     * Constructor.
     */
    DateTimeSkips(final int forValue) {
        value = forValue;
    }

    /*
     * Get integer value for enumerator.
     */
    public int getValue() {
        return value;
    }

    /**
     * @return Get enumeration constant values.
     */
    private static DateTimeSkips[] getEnumConstants() {
        return new DateTimeSkips[] { YEAR, MONTH, DAY, DAY_OF_WEEK, HOUR,
                MINUTE, SECOND, MILLISECOND, DEVITATION, STATUS };

    }

    /**
     * Converts the integer value to enumerated value.
     * 
     * @param value
     *            The integer value, which is read from the device.
     * @return The enumerated value, which represents the integer.
     */
    public static java.util.Set<DateTimeSkips> forValue(final int value) {
        Set<DateTimeSkips> types = new HashSet<DateTimeSkips>();
        DateTimeSkips[] enums = getEnumConstants();
        for (int pos = 0; pos != enums.length; ++pos) {
            if ((enums[pos].value & value) == enums[pos].value) {
                types.add(enums[pos]);
            }
        }
        return types;
    }

    /**
     * Converts the enumerated value to integer value.
     * 
     * @param value
     *            The enumerated value.
     * @return The integer value.
     */
    public static int toInteger(final Set<DateTimeSkips> value) {
        int tmp = 0;
        for (DateTimeSkips it : value) {
            tmp |= it.getValue();
        }
        return tmp;
    }
}

==> gurux.dlms-4.0.70-sources.jar: gurux/dlms/enums/DateTimeSkips.java <==
//
// --------------------------------------------------------------------------
//  Gurux Ltd
// 
//
//
// Filename:        $HeadURL$
//
// Version:         $Revision$,
//                  $Date$
//                  $Author$
//
// Copyright (c) Gurux Ltd
//
//---------------------------------------------------------------------------
//
//  DESCRIPTION
//
// This file is a part of Gurux Device Framework.
//
// Gurux Device Framework is Open Source software; you can redistribute it
// and/or modify it under the terms of the GNU General Public License 
// as published by the Free Software Foundation; version 2 of the License.
// Gurux Device Framework is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of 
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
// See the GNU General Public License for more details.
//
// More information of Gurux products: https://www.gurux.org
//
// This code is licensed under the GNU General Public License v2. 
// Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
//---------------------------------------------------------------------------

package gurux.dlms.enums;

import java.util.HashSet;
import java.util.Set;

/*
 * DataType enumerates skipped fields from date time.
 */
public enum DateTimeSkips {
    /**
     * Year part of date time is skipped.
     */
    YEAR(1),

    /**
     * Month part of date time is skipped.
     */
    MONTH(2),

    /**
     * Day part is skipped.
     */
    DAY(4),

    /**
     * Day of week part of date time is skipped.
     */
    DAY_OF_WEEK(8),

    /**
     * Hours part of date time is skipped.
     */
    HOUR(0x10),

    /**
     * Minute part of date time is skipped.
     */
    MINUTE(0x20),

    /**
     * Second part of date time is skipped.
     */
    SECOND(0x40),

    /**
     * Hundreds of seconds part of date time is skipped.
     */
    MILLISECOND(0x80),

    /**
     * Deviation is not used.
     */
    DEVIATION(0x100),

    /**
     * Status is not used.
     */
    STATUS(0x200);

    private int value;

    /*
     * Constructor.
     */
    DateTimeSkips(final int forValue) {
        value = forValue;
    }

    /*
     * Get integer value for enumerator.
     */
    public int getValue() {
        return value;
    }

    /**
     * @return Get enumeration constant values.
     */
    private static DateTimeSkips[] getEnumConstants() {
        return new DateTimeSkips[] { YEAR, MONTH, DAY, DAY_OF_WEEK, HOUR, MINUTE, SECOND, MILLISECOND, DEVIATION,
                STATUS };

    }

    /**
     * Converts the integer value to enumerated value.
     * 
     * @param value
     *            The integer value, which is read from the device.
     * @return The enumerated value, which represents the integer.
     */
    public static java.util.Set<DateTimeSkips> forValue(final int value) {
        Set<DateTimeSkips> types = new HashSet<DateTimeSkips>();
        DateTimeSkips[] enums = getEnumConstants();
        for (int pos = 0; pos != enums.length; ++pos) {
            if ((enums[pos].value & value) == enums[pos].value) {
                types.add(enums[pos]);
            }
        }
        return types;
    }

    /**
     * Converts the enumerated value to integer value.
     * 
     * @param value
     *            The enumerated value.
     * @return The integer value.
     */
    public static int toInteger(final Set<DateTimeSkips> value) {
        int tmp = 0;
        for (DateTimeSkips it : value) {
            tmp |= it.getValue();
        }
        return tmp;
    }
}
